@@ -1,24 +1,27 @@
 # import from modules
 from .concatenate import Concatenate
 from .conv import Conv1d, Conv2d, Conv3d, Conv
+from .masked_conv2d import MaskedConv2d, MaskedConv2dA, MaskedConv2dB
 from .linear import Linear
 from .log import Log
 from .patching import Patching, PatchEmbedding2d
 from .positional_embedding import PositionalEmbedding
 from .reshape import Reshape
 from .stack import Stack
-# import from other libraries
-from torch.nn import MultiheadAttention as _Attention
-
-Attention = _Attention
+from .vector_quantizer import VectorQuantizer
+from .attention import SeqAttention, ImageAttention
 
 __all__ = [
-    "Attention",
+    "SeqAttention",
+    "ImageAttention",
     "Concatenate",
     "Conv1d",
     "Conv2d",
     "Conv3d",
     "Conv",
+    "MaskedConv2d",
+    "MaskedConv2dA",
+    "MaskedConv2dB",
     "Linear",
     "Log",
     "Patching",
@@ -26,4 +29,5 @@ __all__ = [
     "PositionalEmbedding",
     "Reshape",
     "Stack",
+    "VectorQuantizer",
 ]
